==> Pade_1.0.3.tar.gz: Pade/inst/NEWS.Rd <==
\name{NEWS}
\alias{NEWS}
\title{NEWS file for the Pade package}

\section{Changes in version 1.0.3 (2020-11-10)}{
  \subsection{Fixed}{
    \itemize{
      \item Corrected CRAN requests
    }
  }
}

\section{Changes in version 1.0.2 (2020-11-08)}{
  \subsection{Changed}{
    \itemize{
      \item Changed tests to be compliant with \code{testthat} 3rd edition
      \item Cleaned up documentation
    }
  }
}

\section{Changes in version 1.0.1 (2020-06-02)}{
  \subsection{Added}{
    \itemize{
      \item Added source and ISBN to Description per CRAN request
      \item Added CITATION file
    }
  }
  \subsection{Changed}{
    \itemize{
      \item Cleaned README & NEWS
    }
  }
}

\section{Changes in version 1.0.0 (2019-12-08)}{
  \subsection{Added}{
    \itemize{
      \item Added CRAN version release and date badge
    }
  }
  \subsection{Changed}{
    \itemize{
      \item Incremented to release version
      \item Internal tweaks to project files
    }
  }
}

\section{Changes in version 0.1.5 (2019-10-07)}{
  \subsection{Changed}{
    \itemize{
      \item Moved primary repository from Bitbucket to Github
      \item Changed versioning to more canonic Major.Minor.Patch
      \item Changed example to use lowercase \code{x}
      \item Changed Author description to include ORCID
      \item Added project status badge to README
      \item Added line feeds before and after LaTeX blocks in README
    }
  }
}

\section{Changes in version 0.1-4 (2015-07-29)}{
  \subsection{Bug fixes}{
    \itemize{
      \item Correct the example to evaluate from \eqn{x^0}, not \eqn{x^1},
      by appending \code{-1} to the \code{seq_along} call.
      (Issue #1: Thanks to Anonymous. Note: In move to github, this issue could
      not be transferred.)
    }
  }
}

\section{Changes in version 0.1-3 (2015-06-30)}{
  \subsection{Updates}{
    \itemize{
      \item Update DESCRIPTION and NAMESPACE to explicitly import
      \code{\link[pkg:utils]{head}} and \code{\link[pkg:utils]{tail}} from
      package \code{\link{utils}}
    }
  }
}

\section{Changes in version 0.1-2 (2015-06-10)}{
  \subsection{Updates}{
    \itemize{
      \item Corrected use of grave to proper aigu (Thanks to Dirk Eddelbuettel)
      \item Made polynomial order variable names consistent in documentation
      \item Minor clarifying prose tweaks to documentation
    }
  }
}

\section{Changes in version 0.1-1 (2015-06-09)}{
  \subsection{Added}{
    \itemize{
      \item Initial release
    }
  }
}

==> Pade_1.0.4.tar.gz: Pade/inst/NEWS.Rd <==
\name{NEWS}
\alias{NEWS}
\title{NEWS file for the Pade package}

\section{Changes in version 1.0.4 (2022-01-18)}{
  \subsection{Changed}{
    \itemize{
      \item Converted tests to \code{tinytest} to reduce dependencies
      \item Added DOI to citation
    }
  }
}

\section{Changes in version 1.0.3 (2020-11-10)}{
  \subsection{Fixed}{
    \itemize{
      \item Corrected CRAN requests
    }
  }
}

\section{Changes in version 1.0.2 (2020-11-08)}{
  \subsection{Changed}{
    \itemize{
      \item Changed tests to be compliant with \code{testthat} 3rd edition
      \item Cleaned up documentation
    }
  }
}

\section{Changes in version 1.0.1 (2020-06-02)}{
  \subsection{Added}{
    \itemize{
      \item Added source and ISBN to Description per CRAN request
      \item Added CITATION file
    }
  }
  \subsection{Changed}{
    \itemize{
      \item Cleaned README & NEWS
    }
  }
}

\section{Changes in version 1.0.0 (2019-12-08)}{
  \subsection{Added}{
    \itemize{
      \item Added CRAN version release and date badge
    }
  }
  \subsection{Changed}{
    \itemize{
      \item Incremented to release version
      \item Internal tweaks to project files
    }
  }
}

\section{Changes in version 0.1.5 (2019-10-07)}{
  \subsection{Changed}{
    \itemize{
      \item Moved primary repository from Bitbucket to Github
      \item Changed versioning to more canonic Major.Minor.Patch
      \item Changed example to use lowercase \code{x}
      \item Changed Author description to include ORCID
      \item Added project status badge to README
      \item Added line feeds before and after LaTeX blocks in README
    }
  }
}

\section{Changes in version 0.1-4 (2015-07-29)}{
  \subsection{Bug fixes}{
    \itemize{
      \item Correct the example to evaluate from \eqn{x^0}, not \eqn{x^1},
      by appending \code{-1} to the \code{seq_along} call.
      (Issue #1: Thanks to Anonymous. Note: In move to github, this issue could
      not be transferred.)
    }
  }
}

\section{Changes in version 0.1-3 (2015-06-30)}{
  \subsection{Updates}{
    \itemize{
      \item Update DESCRIPTION and NAMESPACE to explicitly import
      \code{\link[pkg:utils]{head}} and \code{\link[pkg:utils]{tail}} from
      package \code{\link{utils}}
    }
  }
}

\section{Changes in version 0.1-2 (2015-06-10)}{
  \subsection{Updates}{
    \itemize{
      \item Corrected use of grave to proper aigu (Thanks to Dirk Eddelbuettel)
      \item Made polynomial order variable names consistent in documentation
      \item Minor clarifying prose tweaks to documentation
    }
  }
}

\section{Changes in version 0.1-1 (2015-06-09)}{
  \subsection{Added}{
    \itemize{
      \item Initial release
    }
  }
}
